import {select, 
        csv, 
        scaleLinear, 
        extent,
        axisLeft,
        axisBottom,
        format} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');
const margin = {top: 55, right: 40, bottom: 90, left: 135};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const render = data => {

  const title = 'Experience vs Salary';
  
  const xValue = d => d.yrsService;
  const xAxisLabel = 'Years of Service';
  
  const yValue = d => d.salary;
  const yAxisLabel = 'Salary (USD)';
  
  const circleRadius = 10;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight].reverse())
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);

  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const formatYAxis = number => 
  	format(".2s")(number)
  	.replace('k', 'K')
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  	.tickFormat(formatYAxis);
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.select('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -93)
  	.attr('x', -innerHeight/2)
  	.text(yAxisLabel)
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
  	.attr('text-anchor', 'middle');
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 75)
  	.attr('x', innerWidth / 2)
  	.text(xAxisLabel)
  	.attr('fill', 'black');
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  	.attr('cx', d => xScale(xValue(d)))
  	.attr('cy', d => yScale(yValue(d)))
  	.attr('r', 0)
  		.transition().duration(1200)
  	.attr('r', circleRadius);
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('y', -10)
  	.text(title);
  
};

csv('data.csv')
  .then(data => {
  
    data.forEach(d => {
     d.salary = +d.salary;
      d.yrsService = +d['yrs.service'];
      delete d['yrs.service'];
      d.yrsSincePhd = +d['yrs.since.phd'];
      delete d['yrs.since.phd'];
     /*  d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.mpg = +d.mpg;
      d.weight = +d.weight;
      d.year = +d.year;*/
    });
  	  data = data.filter(d => d.yrsService > 2)
    render(data);
  console.log(data)
});













